@@ -1,10 +1,10 @@
-use rand::seq::SliceRandom;
-use rand::Rng;
 use std::thread;
 use std::time::{Duration, Instant};
 
 use console::{style, Emoji};
 use indicatif::{HumanDuration, MultiProgress, ProgressBar, ProgressStyle};
+use rand::seq::SliceRandom;
+use rand::Rng;
 
 static PACKAGES: &[&str] = &[
     "fs-events",
@@ -35,9 +35,9 @@ static SPARKLE: Emoji<'_, '_> = Emoji("✨ ", ":-)");
 pub fn main() {
     let mut rng = rand::thread_rng();
     let started = Instant::now();
-    let spinner_style = ProgressStyle::default_spinner()
-        .tick_chars("⠁⠂⠄⡀⢀⠠⠐⠈ ")
-        .template("{prefix:.bold.dim} {spinner} {wide_msg}");
+    let spinner_style = ProgressStyle::with_template("{prefix:.bold.dim} {spinner} {wide_msg}")
+        .unwrap()
+        .tick_chars("⠁⠂⠄⡀⢀⠠⠐⠈ ");
 
     println!(
         "{} {}Resolving packages...",
@@ -69,24 +69,29 @@ pub fn main() {
         PAPER
     );
     let m = MultiProgress::new();
-    for i in 0..4 {
-        let count = rng.gen_range(30..80);
-        let pb = m.add(ProgressBar::new(count));
-        pb.set_style(spinner_style.clone());
-        pb.set_prefix(format!("[{}/?]", i + 1));
-        let _ = thread::spawn(move || {
-            let mut rng = rand::thread_rng();
-            let pkg = PACKAGES.choose(&mut rng).unwrap();
-            for _ in 0..count {
-                let cmd = COMMANDS.choose(&mut rng).unwrap();
-                pb.set_message(format!("{}: {}", pkg, cmd));
-                pb.inc(1);
-                thread::sleep(Duration::from_millis(rng.gen_range(25..200)));
-            }
-            pb.finish_with_message("waiting...");
-        });
+    let handles: Vec<_> = (0..4u32)
+        .map(|i| {
+            let count = rng.gen_range(30..80);
+            let pb = m.add(ProgressBar::new(count));
+            pb.set_style(spinner_style.clone());
+            pb.set_prefix(format!("[{}/?]", i + 1));
+            thread::spawn(move || {
+                let mut rng = rand::thread_rng();
+                let pkg = PACKAGES.choose(&mut rng).unwrap();
+                for _ in 0..count {
+                    let cmd = COMMANDS.choose(&mut rng).unwrap();
+                    pb.set_message(format!("{}: {}", pkg, cmd));
+                    pb.inc(1);
+                    thread::sleep(Duration::from_millis(rng.gen_range(25..200)));
+                }
+                pb.finish_with_message("waiting...");
+            })
+        })
+        .collect();
+    for h in handles {
+        let _ = h.join();
     }
-    m.join_and_clear().unwrap();
+    m.clear().unwrap();
 
     println!("{} Done in {}", SPARKLE, HumanDuration(started.elapsed()));
 }
